@@ -167,7 +167,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckPhoneAndName(self, request):
-        """本接口用于校验手机号和姓名的真实性和一致性。
+        """手机号二要素核验接口用于校验手机号和姓名的真实性和一致性，支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for CheckPhoneAndName.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckPhoneAndNameRequest`
@@ -699,7 +699,7 @@ class FaceidClient(AbstractClient):
 
 
     def PhoneVerification(self, request):
-        """本接口用于校验手机号、姓名和身份证号的真实性和一致性。
+        """本接口用于校验手机号、姓名和身份证号的真实性和一致性。支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
         :param request: Request instance for PhoneVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationRequest`
